@@ -115,12 +115,10 @@ void constructReg::descriptionString(char* const Str)
    switch(countType)
    {
       case aCONTINUOUS:
-           //sprintf(Str,"[%d] %s <= %f", splitEstimator, dscrStr, splitValue) ;
-           sprintf(Str,"%s <= %f", dscrStr, splitValue) ;
+            snprintf(Str, MaxFeatureStrLen, "%s <= %f", dscrStr, splitValue) ;
            break ;
       case aDISCRETE:
-           //sprintf(Str, "[%d] %s", splitEstimator, dscrStr) ;
-           sprintf(Str, "%s", dscrStr) ;
+           snprintf(Str, MaxFeatureStrLen, "%s", dscrStr) ;
            if (compositionType == cSINGLEattribute)
            { 
              strcat(Str, "= (") ; 
@@ -162,36 +160,36 @@ char* constructReg::description(constructRegNode *Node)
    switch(Node->nodeType)
    {
       case cnDISCattrValue:
-           sprintf(Str, "(%s = %s)", gRT->AttrDesc[gRT->DiscIdx[Node->attrIdx]].AttributeName,
+           snprintf(Str, MaxFeatureStrLen, "(%s = %s)", gRT->AttrDesc[gRT->DiscIdx[Node->attrIdx]].AttributeName,
                                    gRT->AttrDesc[gRT->DiscIdx[Node->attrIdx]].ValueName[Node->valueIdx-1] ) ;
            break ;          
       case cnCONTattrValue:
            if (Node->lowerBoundary == -DBL_MAX)
-              sprintf(Str, "(%s <= %.3f)", gRT->AttrDesc[gRT->ContIdx[Node->attrIdx]].AttributeName,
+              snprintf(Str, MaxFeatureStrLen, "(%s <= %.3f)", gRT->AttrDesc[gRT->ContIdx[Node->attrIdx]].AttributeName,
                                            Node->upperBoundary ) ;
            else
              if (Node->upperBoundary == DBL_MAX)
-                sprintf(Str, "(%s > %.3f)", gRT->AttrDesc[gRT->ContIdx[Node->attrIdx]].AttributeName,
+                snprintf(Str, MaxFeatureStrLen, "(%s > %.3f)", gRT->AttrDesc[gRT->ContIdx[Node->attrIdx]].AttributeName,
                                            Node->lowerBoundary ) ;
              else
-                sprintf(Str, "(%.3f < %s <= %.3f)", Node->lowerBoundary,
+                snprintf(Str, MaxFeatureStrLen, "(%.3f < %s <= %.3f)", Node->lowerBoundary,
                                                     gRT->AttrDesc[gRT->ContIdx[Node->attrIdx]].AttributeName,
                                                     Node->upperBoundary ) ;
            break ;
       
       case cnCONTattribute:
-           sprintf(Str,"%s", gRT->AttrDesc[gRT->ContIdx[Node->attrIdx]].AttributeName) ;
+           snprintf(Str, MaxFeatureStrLen, "%s", gRT->AttrDesc[gRT->ContIdx[Node->attrIdx]].AttributeName) ;
            break ;
       
       case cnDISCattribute:
-           sprintf(Str, "%s", gRT->AttrDesc[gRT->DiscIdx[Node->attrIdx]].AttributeName) ;
+           snprintf(Str, MaxFeatureStrLen, "%s", gRT->AttrDesc[gRT->DiscIdx[Node->attrIdx]].AttributeName) ;
            break ;
 
       case cnAND:
          {
             char *leftStr = description(Node->left) ;
             char *rightStr = description(Node->right) ;
-            sprintf(Str, "%s & %s", leftStr, rightStr) ;
+            snprintf(Str, MaxFeatureStrLen, "%s & %s", leftStr, rightStr) ;
             delete [] leftStr ;
             delete [] rightStr ;
          }
@@ -200,7 +198,7 @@ char* constructReg::description(constructRegNode *Node)
          {
             char *leftStr = description(Node->left) ;
             char *rightStr = description(Node->right) ;
-            sprintf(Str, "%s * %s", leftStr, rightStr) ;
+            snprintf(Str, MaxFeatureStrLen, "%s * %s", leftStr, rightStr) ;
             delete [] leftStr ;
             delete [] rightStr ;
          }
@@ -209,7 +207,7 @@ char* constructReg::description(constructRegNode *Node)
          {
             char *leftStr = description(Node->left) ;
             char *rightStr = description(Node->right) ;
-            sprintf(Str, "%s + %s", leftStr, rightStr) ;
+            snprintf(Str, MaxFeatureStrLen, "%s + %s", leftStr, rightStr) ;
             delete [] leftStr ;
             delete [] rightStr ;
          }
