@@ -1,8 +1,7 @@
-#include <stdio.h>
-#include <stddef.h>
-#include <stdlib.h>
-#include <limits.h>
-#include <float.h>
+#include <cstddef>
+#include <cstdlib>
+#include <climits>
+#include <cfloat>
 
 #include "general.h"
 #include "error.h"
@@ -10,6 +9,8 @@
 #define NR_END 1
 #define FREE_ARG char*
 
+using namespace std ;
+
 void nrmerror(const char *error_text)
 {
    stop("Numerical library run-time error",error_text);
